@@ -19,12 +19,12 @@ class DrawRectComponent(Component) :
     def update(self,dt) :
         pg.draw.rect(Game.get().surface, self.color,((
                                                  int(self.parent.relativeTransform.position.x - (Camera.DX+Camera.PX)*(not self.parent.fixed)),
-                                                 int(self.parent.relativeTransform.position.y - (Camera.DY+Camera.PY)*(not self.parent.fixed)) ),
-                                                 (int(self.parent.relativeTransform.scale.x * Camera.ZX*(not self.parent.fixed)),
-                                                  int(self.parent.relativeTransform.scale.y * Camera.ZY*(not self.parent.fixed)))))
+                                                 int(self.parent.relativeTransform.position.y - (Camera.DY+Camera.PY)*(not self.parent.fixed))),
+                                                 (int(self.parent.relativeTransform.scale.x * Camera.ZX if (not self.parent.fixed) else self.parent.relativeTransform.scale.x),
+                                                  int(self.parent.relativeTransform.scale.y * Camera.ZY if (not self.parent.fixed) else self.parent.relativeTransform.scale.y))))
 
     def getSprite(self) :
         return self.sprite
 
     def setSprite(self, sprite) :
-        self.sprite = sprite
\ No newline at end of file
+        self.sprite = sprite
